package com.biftechnologies.membership.web.screens.firebasependinginvites;

import com.biftechnologies.membership.entity.FirebasePendingInvites;
import com.haulmont.cuba.core.global.View;
import com.haulmont.cuba.gui.UiComponents;
import com.haulmont.cuba.gui.components.*;
import com.haulmont.cuba.gui.components.actions.BaseAction;
import com.haulmont.cuba.gui.components.data.options.ContainerOptions;
import com.haulmont.cuba.gui.components.data.value.ContainerValueSource;
import com.haulmont.cuba.gui.model.*;
import com.haulmont.cuba.gui.screen.*;
import com.haulmont.cuba.security.entity.Group;
import com.haulmont.cuba.security.entity.Role;
import org.slf4j.Logger;

import javax.inject.Inject;

@UiController("membership_FirebasePendingInviteScreen")
@UiDescriptor("firebase-pending-invite-screen.xml")
public class FirebasePendingInviteScreen extends Screen {

    @Inject
    private UiComponents uiComponents;
    @Inject
    private DataComponents dataComponents;
    @Inject
    private Form firebasePendingInvitesForm;
    @Inject
    private Button manualAddFieldsBtn;
    @Inject
    private Logger log;

    private InstanceContainer<FirebasePendingInvites> firebasePendingInvitesDc;

    private CollectionContainer<Role> rolesDc;

    private CollectionContainer<Group> groupsDc;

    private CollectionLoader<Role> rolesDl;

    private CollectionLoader<Group> groupsDl;

    @Subscribe
    public void onInit(InitEvent event) {
        createDataComponents();
        groupsDl.load();
        rolesDl.load();
        addFields();
    }

    private void createDataComponents() {
        DataContext dataContext = dataComponents.createDataContext();
        getScreenData().setDataContext(dataContext);

        firebasePendingInvitesDc = dataComponents.createInstanceContainer(FirebasePendingInvites.class);
        FirebasePendingInvites firebasePendingInvites = dataContext.create(FirebasePendingInvites.class);
        firebasePendingInvitesDc.setItem(firebasePendingInvites);

        InstanceLoader<FirebasePendingInvites> firebasePendingInvitesDl = dataComponents.createInstanceLoader();
        firebasePendingInvitesDl.setContainer(firebasePendingInvitesDc);
        firebasePendingInvitesDl.setDataContext(dataContext);
        firebasePendingInvitesDl.setView("firebasePendingInvites-view");

        groupsDc = dataComponents.createCollectionContainer(Group.class);

        groupsDl = dataComponents.createCollectionLoader();
        groupsDl.setContainer(groupsDc);
        groupsDl.setDataContext(dataContext);
        groupsDl.setQuery("select e from sec$Group e");
        groupsDl.setView(View.MINIMAL);

        rolesDc = dataComponents.createCollectionContainer(Role.class);

        rolesDl = dataComponents.createCollectionLoader();
        rolesDl.setContainer(rolesDc);
        rolesDl.setDataContext(dataContext);
        rolesDl.setQuery("select e from sec$Role e");
        rolesDl.setView(View.MINIMAL);
    }

    @Subscribe
    public void onBeforeShow(BeforeShowEvent event) {
        manualAddFieldsBtn.setAction(new BaseAction("manualAddFields") {
            @Override
            public void actionPerform(Component component) {
                addFields();
            }
        });
    }

    private void addFields() {

        TextField<String> email = uiComponents.create(TextField.TYPE_STRING);
        email.setId("emailField");
        email.setCaption("Email");
        email.setValueSource(new ContainerValueSource<>(firebasePendingInvitesDc, "email"));

        LookupField<Group> groupField = uiComponents.create(LookupField.of(Group.class));
        groupField.setId("groupField");
        groupField.setCaption("Group");
        groupField.setNullOptionVisible(false);
        groupField.setValueSource(new ContainerValueSource<>(firebasePendingInvitesDc, "group"));
        groupField.setOptions(new ContainerOptions<>(groupsDc));
        groupField.setValue(groupsDc.getItems().get(0));

        LookupField<Role> roleField = uiComponents.create(LookupField.of(Role.class));
        roleField.setId("roleField");
        roleField.setCaption("Role");
        roleField.setNullOptionVisible(false);
        roleField.setValueSource(new ContainerValueSource<>(firebasePendingInvitesDc, "role"));
        roleField.setOptions(new ContainerOptions<>(rolesDc));
        roleField.setValue(rolesDc.getItems().get(0));

        firebasePendingInvitesForm.add(email, 0);
        firebasePendingInvitesForm.add(groupField, 1);
        firebasePendingInvitesForm.add(roleField, 2);
    }

    @Subscribe("manualSubmitBtn")
    public void onManualSubmitBtnClick(Button.ClickEvent event) {

    }
}